======================
Manipulation/selection
======================

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    LazyFrame.approx_n_unique
    LazyFrame.bottom_k
    LazyFrame.cast
    LazyFrame.clear
    LazyFrame.clone
    LazyFrame.drop
    LazyFrame.drop_nulls
    LazyFrame.explode
    LazyFrame.fill_nan
    LazyFrame.fill_null
    LazyFrame.filter
    LazyFrame.first
    LazyFrame.gather_every
    LazyFrame.group_by
    LazyFrame.group_by_dynamic
    LazyFrame.head
    LazyFrame.inspect
    LazyFrame.interpolate
    LazyFrame.join
    LazyFrame.join_asof
    LazyFrame.join_where
    LazyFrame.last
    LazyFrame.limit
    LazyFrame.melt
    LazyFrame.merge_sorted
    LazyFrame.rename
    LazyFrame.reverse
    LazyFrame.rolling
    LazyFrame.select
    LazyFrame.select_seq
    LazyFrame.set_sorted
    LazyFrame.shift
    LazyFrame.slice
    LazyFrame.sort
    LazyFrame.sql
    LazyFrame.tail
    LazyFrame.top_k
    LazyFrame.unique
    LazyFrame.unnest
    LazyFrame.unpivot
    LazyFrame.update
    LazyFrame.with_columns
    LazyFrame.with_columns_seq
    LazyFrame.with_context
    LazyFrame.with_row_count
    LazyFrame.with_row_index
